@@ -1,23 +1,21 @@
 # -*- coding: utf-8 -*-
-from math import log
-
-from AccessControl import getSecurityManager
-from AccessControl.Permissions import view_management_screens
-from Acquisition import aq_inner
 from collective.revisionmanager import _
-from collective.revisionmanager.interfaces import (IHistoryStatsCache,
-                                                   IRevisionSettingsSchema)
+from collective.revisionmanager.interfaces import IHistoryStatsCache
+from collective.revisionmanager.interfaces import IRevisionSettingsSchema
+from math import log
 from plone import api
 from plone.autoform.form import AutoExtensibleForm
 from plone.batching import Batch
 from plone.protect import CheckAuthenticator
 from Products.CMFPlone.interfaces import IPloneSiteRoot
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
-from z3c.form import button, form
-from zope.component import adapter, getUtility
+from six.moves import zip
+from z3c.form import button
+from z3c.form import form
+from zope.component import adapter
+from zope.component import getUtility
 from zope.interface import implementer
 from zope.publisher.browser import BrowserPage
-from six.moves import zip
 
 
 class HistoriesListView(BrowserPage):
@@ -170,9 +168,13 @@ class RevisionsControlPanel(AutoExtensibleForm, form.EditForm):
         self.statscache = getUtility(IHistoryStatsCache)
 
     def available(self):
-        root = aq_inner(self.context).getPhysicalRoot()
-        sm = getSecurityManager()
-        return sm.checkPermission(view_management_screens, root)
+        # We used to check for the
+        # AccessControl.Permissions.view_management_screens
+        # permission on the *Zope* root, but that seems unneeded.
+        # It is enough to check Manage Portal permission in zcml.
+        # See https://github.com/collective/collective.revisionmanager/issues/30
+        # Let's keep the method though, so people can override it.
+        return True
 
     def summaries(self):
         return self.statscache.get('summaries')
